c# genfam.f
C--------------------------------
      SUBROUTINE GENFAM(rlat,IBLK,FREQ,Z,FA,DUA,DLA,DMS,DUS,DLS)
c**********************************************************************
c          Re-written 3.June.93 by Greg Hand because previous version was
c          really incorrect. It made an attempt to limit Sigma Fam (DMS)
c          to a 10 MHz frequency, but the indicies I and J became
c          confused, and the result was not correct. Ironically,
c          Sigma Fam was the only result that was computed correctly.
c          DUA, DLA, DUS, DLS were all incorrect.  This current
c          version should limit DMS to 10 MHz and the others to 20 MHz
c          because their curves end at 20 MHz. Unfortunately, this error
c          has probably existed since time began, and it may take a
c          while for this corrected version to propagate into all version
c          that exist. The magnitude of the errors in DUA, DLA, DUS, DLS
c          could approach +/- 4dB at 20MHz.  However, for use in
c          propagation prediction programs such as IONCAP, these errors
c          are almost unnoticable because Atmospheric Noise is not
c          the driving force at HF frequencies.
c**********************************************************************
c          INPUTs:
c              rlat = latitude of point of interest
c                   only cares if + or - to flip Northern/Southern Hemisphere
c              IBLK = time block of interest (local time 1=0000-0400)
c              FREQ = Frequency in MHz
c              Z = 1 MHz Fam value
c**********************************************************************
c          OUTPUTs:
c              FA = Frequency variation of Fam
c              DUA = Du = ratio of upper decile to median value (Fam)
c              DLA = Dl = ratio of median value (Fam) to lower decile
c              DMS = Sigma Fam = standard deviation of values of Fam
c              DUS = Sigma Du  = standard deviation of values of Du
c              DLS = Sigma Dl  = standard deviation of values of Dl
c**********************************************************************
C--------------------------------

C     GENFAM CALCULATES THE FREQUENCY DEPENDENCE OF THE ATMOSPHERIC
C     NOISE AND GETS DECILES AND PREDICTION ERRORS FROM TABLES
C
      common /c_season/ mode_s1,mode_s2  !  mode_s2=1=interpolate
      COMMON / TWO / F2D(16,6,6), P(29,16,8), ABP(2,9), DUD(5,12,5),
     A FAM(14,12), SYS(9,16,6), PERR(9,4,6)
      DIMENSION V(5),v2(5)
      data RLAT_MAX/23.5/    !  max interpoation latitude, Tropic of Cancer/Capricorn
C.....
      IBK=IBLK
C.....CHECK IF LATITUDE IS NORTH OR SOUTH
      IF(rlat.lt.0.) IBK=IBK+6
      U1 = -.75
      X = ALOG10(FREQ)
      U = (8. * 2.**X - 11.) /4.
      KOP = 1
 110  PZ = U1*FAM(1,IBK) + FAM(2,IBK)
      PX = U1*FAM(8,IBK) + FAM(9,IBK)
      DO 115 I=3,7
      PZ = U1*PZ + FAM(I  ,IBK)
 115  PX = U1*PX + FAM(I+7,IBK)
      IF(KOP.eq.1) then
         CZ = Z * PZ + PX
         CZ = Z + Z - CZ
         U1 = U
         KOP = 2
         GO TO 110
      end if
      FA = CZ*PZ + PX
ccc      write(81,1) iblk,(fam(i,iblk),i=1,14)
ccc1     format('fam(',i2,')=',7f10.4,/,8x,7f10.4)
ccc      write(81,1) iblk+6,(fam(i,iblk+6),i=1,14)
c***********************************************************
      jbk=ibk+6
      if(jbk.gt.12) jbk=jbk-12
      rlatd=rlat/.0174533    !  convert to degrees
c          Limit frequency to 20 MHz for DUA, DLA, DUS, DLS
c            because curves in REP 322 only go to 20 MHz
      if(FREQ.gt.20.) X=ALOG10(20.)
      DO 145 I = 1, 5
c          Limit frequency to 10 MHz for DMS (Sigma Fam)
c            because curves in REP 322 only go to 10 MHz
      if(I.eq.5 .and. FREQ.gt.10.) X=1.
      Y = DUD(1,IBK,I)
      Y2= DUD(1,jBK,I)
      DO 140 J = 2,5
      Y = Y*X + DUD(J,IBK,I)
      Y2= Y2*X + DUD(J,jBK,I)
 140  continue
      V(I) = Y
      V2(I) = Y2
 145  continue
ccc      write(81,2) iblk,(dud(j,iblk,1),j=1,5)
ccc2     format('dud(',i2,')=',5f10.4)
ccc      write(81,2) iblk+6,(dud(j,iblk+6,1),j=1,5)
      if(mode_s2.ne.1) go to 900   !  no interpolation
      if(abs(rlatd).gt.RLAT_MAX) go to 900  !  no interpolation
         fact=(abs(rlatd)+RLAT_MAX)/RLAT_MAX/2.
ccc      write(*,4) fact,v(1),v2(1)
ccc4     format('fact=',3f9.4)
         do 150 i=1,5
150      v(i)=v2(i) + (v(i)-v2(i))*fact
900   DUA = V(1)
      DLA = V(2)
      DUS = V(3)
      DLS = V(4)
      DMS = V(5)
ccc      write(*,3) ibk,jbk,rlatd,z,fa,dua,dla,dus,dls,dms
ccc3     format('genfam=',2i3,8f9.4)
      RETURN
      END
